@@ -1,8 +1,5 @@
 #include <stdio.h>
 #include <stdlib.h>
-/*
-#include <math.h>
-*/
 #include <float.h>
 #include "map.h"
 
@@ -13,42 +10,108 @@
 #define Max(a,b)	((a) > (b) ? (a) : (b))
 #define R2FMT		"%hd%hd"	/* format for reading two Region's */
 
+#define WORDSIZE 100
+
 char Usage[] = "Usage: %s a in-file in-file-statsfile out-file\n   or: %s b in-file in-file-statsfile out-file binary-line-file";
 char *Me, *getword(), *Infile, *Linefile;
 FILE *Lin;
 Region n;
-int np, maxl;
+long int np, maxl;
 
-main(ac, av)
-char *av[];
+extern int
+isspace(int c);
+
+int
+fatal(s, a, b)
+char *s;
 {
-
-	FILE *in, *in2, *out;
-	int ascii;
-
-	Me = av[0];
-	if(ac < 5)
-		fatal(Usage, Me);
-	ascii = *av[1] == 'a';
-	if(ac != (ascii ? 5 : 6))
-		fatal(Usage, Me);
-	Infile = av[2];
-	if((in = fopen(av[2], "rb")) == NULL)
-		fatal("Cannot open %s for reading", av[2]);
-	if((in2 = fopen(av[3], "rb")) == NULL)
-                fatal("Cannot open %s for reading", av[3]);
-	if(fscanf(in2, "%ld%ld", &np, &maxl) != 2)
-		fatal("Cannot read stats data file %s", av[3]);
-	n = np;	/* won't read directly */
-	if((out = fopen(av[4], "wb")) == NULL)
-		fatal("Cannot open %s for writing", av[4]);
-	Linefile = av[5];
-	if(!ascii && (Lin = fopen(av[5], "rb")) == NULL)
-		fatal("Cannot open %s for reading", av[5]);
-	ascii ? to_ascii(in, out) : to_binary(in, out);
-	exit(0);
+	fprintf(stderr, s, a, a, b);
+	fprintf(stderr, "\n");
+	exit(1);
 }
 
+/*
+ * Read one polyline number.  The return value should be
+ * 1 if a number was read, 0 if the end-of-record indicator was
+ * read and -1 if there was a read fatal.
+ */
+int
+getpoly(f, r)
+FILE *f;
+Polyline *r;
+{
+	char *w;
+
+	if((w = getword(f)) == 0)
+		return(-1);
+	if(strcmp(w, EOR) == 0)
+		return(0);
+	*r = atoi(w);
+	return(1);
+}
+
+char *
+getword(f)
+FILE *f;
+{
+	static char word[WORDSIZE];
+	char *s = word;
+	int c;
+
+	do
+		if((c = fgetc(f)) < 0)
+			return(0);
+	while(isspace(c));
+	do {
+		if(s - word >= WORDSIZE-1)
+			return(0);
+		*s++ = c;
+		c = fgetc(f);
+	} while(c >= 0 && !isspace(c));
+	*s++ = 0;
+	return(word);
+}
+
+void
+set_range(rh, r)
+struct region_h *rh;
+Polyline r[];
+{
+	int n = rh->nline;
+	struct line_h *lh, *get_lh();
+	float xmin = FLT_MAX, ymin = FLT_MAX;
+	float xmax = -FLT_MAX, ymax = -FLT_MAX;
+
+	while(n--) {
+		lh = get_lh(ABS(*r));
+		xmin = MIN(xmin, lh->sw.x);
+		xmax = MAX(xmax, lh->ne.x);
+		ymin = MIN(ymin, lh->sw.y);
+		ymax = MAX(ymax, lh->ne.y);
+		r++;
+	}
+	rh->sw.x = xmin;
+	rh->sw.y = ymin;
+	rh->ne.x = xmax;
+	rh->ne.y = ymax;
+}
+
+struct line_h *
+get_lh(r)
+Polyline r;
+{
+	static struct line_h lh;
+	int seek;
+
+	seek = sizeof(int) + sizeof(Polyline) + (r-1)*sizeof(struct line_h);
+	if(Seek(Lin, seek) == -1)
+		fatal("Cannot seek to header in %s", Linefile);
+	if(Read(Lin, &lh, 1) != 1)
+		fatal("Cannot read header in %s", Linefile);
+	return(&lh);
+}
+
+void
 to_ascii(in, out)
 FILE *in, *out;
 {
@@ -93,6 +156,7 @@ FILE *in, *out;
 	}
 }
 
+void
 to_binary(in, out)
 FILE *in, *out;
 {
@@ -129,94 +193,33 @@ FILE *in, *out;
 		fatal("Cannot write headers to output file");
 }
 
-/*
- * Read one polyline number.  The return value should be
- * 1 if a number was read, 0 if the end-of-record indicator was
- * read and -1 if there was a read fatal.
- */
-getpoly(f, r)
-FILE *f;
-Polyline *r;
+int
+main(ac, av)
+char *av[];
 {
-	char *w;
 
-	if((w = getword(f)) == 0)
-		return(-1);
-	if(strcmp(w, EOR) == 0)
-		return(0);
-	*r = atoi(w);
-	return(1);
-}
-
-#define WORDSIZE 100
-
-char *
-getword(f)
-FILE *f;
-{
-	static char word[WORDSIZE];
-	char *s = word;
-	int c;
-
-	do
-		if((c = fgetc(f)) < 0)
-			return(0);
-	while(isspace(c));
-	do {
-		if(s - word >= WORDSIZE-1)
-			return(0);
-		*s++ = c;
-		c = fgetc(f);
-	} while(c >= 0 && !isspace(c));
-	*s++ = 0;
-/*fprintf(stderr, "%s\n", word);
-*/
-	return(word);
-}
-
-set_range(rh, r)
-struct region_h *rh;
-Polyline r[];
-{
-	int n = rh->nline;
-	struct line_h *lh, *get_lh();
-	float xmin = FLT_MAX, ymin = FLT_MAX;
-	float xmax = -FLT_MAX, ymax = -FLT_MAX;
-
-	while(n--) {
-		lh = get_lh(ABS(*r));
-		xmin = MIN(xmin, lh->sw.x);
-		xmax = MAX(xmax, lh->ne.x);
-		ymin = MIN(ymin, lh->sw.y);
-		ymax = MAX(ymax, lh->ne.y);
-		r++;
-	}
-	rh->sw.x = xmin;
-	rh->sw.y = ymin;
-	rh->ne.x = xmax;
-	rh->ne.y = ymax;
-}
-
-struct line_h *
-get_lh(r)
-Polyline r;
-{
-	static struct line_h lh;
-	int seek;
-
-	seek = sizeof(int) + sizeof(Polyline) + (r-1)*sizeof(struct line_h);
-	if(Seek(Lin, seek) == -1)
-		fatal("Cannot seek to header in %s", Linefile);
-	if(Read(Lin, &lh, 1) != 1)
-		fatal("Cannot read header in %s", Linefile);
-	return(&lh);
-}
-
-/* VARARGS */
-fatal(s, a, b)
-char *s;
-{
-	fprintf(stderr, s, a, a, b);
-	fprintf(stderr, "\n");
-	exit(1);
+	FILE *in, *in2, *out;
+	int ascii;
+
+	Me = av[0];
+	if(ac < 5)
+		fatal(Usage, Me);
+	ascii = *av[1] == 'a';
+	if(ac != (ascii ? 5 : 6))
+		fatal(Usage, Me);
+	Infile = av[2];
+	if((in = fopen(av[2], "rb")) == NULL)
+		fatal("Cannot open %s for reading", av[2]);
+	if((in2 = fopen(av[3], "rb")) == NULL)
+                fatal("Cannot open %s for reading", av[3]);
+	if(fscanf(in2, "%ld%ld", &np, &maxl) != 2)
+		fatal("Cannot read stats data file %s", av[3]);
+	n = np;	/* won't read directly */
+	if((out = fopen(av[4], "wb")) == NULL)
+		fatal("Cannot open %s for writing", av[4]);
+	Linefile = av[5];
+	if(!ascii && (Lin = fopen(av[5], "rb")) == NULL)
+		fatal("Cannot open %s for reading", av[5]);
+	ascii ? to_ascii(in, out) : to_binary(in, out);
+	exit(0);
 }
